@@ -244,8 +244,9 @@ class dbthinger:
 
 		"""
 		try:
-			#print(sql)
+
 			return_fmt = self.postgres_db.queryone(sql)
+
 			if return_fmt == 'Good':
 				return True
 			else:
@@ -315,6 +316,7 @@ class schemawiz:
 			tablename = sztablename
 
 		if not self.dbthings.postgres_db.does_table_exist(tablename):
+			print(ddl)
 			self.dbthings.postgres_db.execute(ddl)
 
 			self.dbthings.postgres_db.load_csv_to_table(csvfilename,tablename,True,delimiter)
@@ -353,6 +355,7 @@ class schemawiz:
 			tablename = sztablename
 
 		if not self.dbthings.mysql_db.does_table_exist(tablename):
+			print(ddl)
 			self.dbthings.mysql_db.execute(ddl)
 
 			self.dbthings.mysql_db.load_csv_to_table(csvfilename,tablename,True,delimiter)
@@ -822,12 +825,25 @@ class schemawiz:
 
 
 if __name__ == '__main__':
-	csvfilename = 'sample.csv' # input('csvfile to read? ')
+	csvfilename = input('csvfile to read? ')
 
-	obj = schemawiz()
+	obj = schemawiz(csvfilename)
+
+	ddl = obj.guess_postgres_ddl(csvfilename.replace('.','_'))
+	print(ddl)
 
 
 	"""
+
+	print('/* Postgres DDL - BEGIN ----- schemawiz().guess_postgres_ddl() ----- */ \n')
+	ddl = obj.guess_postgres_ddl(csvfilename.replace('.','_'))
+	print('/* Tablename used : ' + obj.lastcall_tablename + ' */ \n')
+	print(ddl)
+	print('/* Postgres DDL - END   ----- ----- ----- ----- */ \n')
+	
+	
+	
+	
 	print(obj.dbthings.postgres_db.does_table_exist('newtbl'))
 
 	# add any specific known date formats
@@ -835,8 +851,6 @@ if __name__ == '__main__':
 	if csvfilename != '':
 		obj.loadcsvfile(csvfilename)
 
-	r = obj.createload_postgres_from_csv(csvfilename)
-	print(r + ' created.')
 
 
 
